@@ -8,8 +8,8 @@ class Tools(object):
     def __init__(self):
         super(Tools, self).__init__()
         
-    def writeToCsv(self,fname,df,sep=None):
-        df.to_csv(fname, sep=sep, encoding='utf-8', lines=False)
+    def writeToCsv(self,fname,df,sep='\t'):
+        df.to_csv(fname, sep=sep, encoding='utf-8')
     
     def writeToJson(self,fname,df):
         df.to_json(fname, orient='records', lines=False)
@@ -26,7 +26,7 @@ class Tools(object):
         result = json.loads(result.decode('latin-1'))
         return result
 
-    def readCsvToJson(self,file,xdelimiter=None):
+    def readCsvToJson(self,file,xdelimiter='\t'):
         df = pd.read_csv(file,delimiter=xdelimiter)
         result = df.to_json(orient='records', lines=False)
         result = json.loads(result.decode('latin-1'))
@@ -68,7 +68,7 @@ class Tools(object):
         return datas
 
     def altoOptimizer(self,fname,df2):
-        df1 = pd.DataFrame()
+        data = pd.DataFrame()
         if(os.path.isfile(fname)):
             df1 = pd.DataFrame(self.readCsvToJson(fname))
             merged = df1.merge(df2, indicator=True, how='outer')
